==> nextcloud-23.0.8.tgz: nextcloud/apps/survey_client/l10n/el.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Η τελευταία αναφορά στάλθηκε στις: {on}",
    "An error occurred while sending your report." : "Παρουσιάστηκε σφάλμα κατά την αποστολή της αναφοράς σας.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Λίστα εφαρμογών <em>(για κάθε εφαρμογή: όνομα, έκδοση, είναι ενεργοποιημένη;)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Περιβάλλον βάσης δεδομένων <em>(Τύπος, έκδοση, μέγεθος βάσης δεδομένων) </em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Πληροφορίες κρυπτογράφησης <em>(είναι ενεργοποιημένες; , ποιό είναι το προεπιλεγμένο άρθρωμα) </em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Αριθμός διαμοιρασμών<em>(ανά τύπο και ρύθμιση δικαιωμάτων)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Περιβάλλον PHP <em>(έκδοση, όριο μνήμης, μέγιστος χρόνος εκτέλεσης, μέγιστο μέγεθος αρχείου)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Λεπτομέρειες διακομιστή <em>(έκδοση, χρήση memcache, κατάσταση των locking/previews/avatars)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Στατιστικά <em>(αριθμός αρχείων, χρηστών, μονάδων αποθήκευσης ανά τύπο, σχόλια και ετικέτες)</em>",
    "Usage survey" : "Έρευνα χρήσης",
    "Help improve Nextcloud" : "Βοηθήστε στην βελτίωση του Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Θέλετε να μας βοηθήσετε να βελτιώσουμε το Nextcloud παρέχοντας κάποια ανώνυμα δεδομένα σχετικά με τις ρύθμισεις και τη χρήση; Μπορείτε να την απενεργοποιήσετε ανά πάσα στιγμή από τις ρυθμίσεις διαχειριστή ξανά.",
    "Not now" : "Όχι τώρα",
    "Send usage" : "Αποστολή χρήσης",
    "Never" : "Ποτέ",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Στέλνει ανώνυμα δεδομένα στο Nextcloud για να μας βοηθήσει να βελτιώσουμε το Nextcloud.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Μπορείτε να βοηθήσετε στη βελτίωση του Nextcloud με την αποστολή ορισμένων στοιχείων σχετικά με τις τρέχουσες ρυθμίσεις και τη χρήση.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Παίρνουμε στα σοβαρά τα προσωπικά σας δεδομένα. Η αποστολή δεδομένων είναι απενεργοποιημένη από προεπιλογή και αν επιλέξετε να την ενεργοποιήσετε, θα είναι ανώνυμη πρώτα και θα σας δοθεί η δυνατότητα τι ακριβώς θα μοιραστείτε. Μόλις ληφθεί μια αναφορά, η προηγούμενη καταργείται. Μεταφορτώστε μια καθαρή αναφορά για να διαγράψετε όλα τα δεδομένα που είναι αποθηκευμένα στο διακομιστή.",
    "Send new report now" : "Αποστολή νέας αναφοράς τώρα",
    "Send usage survey monthly" : "Αποστολή έρευνας χρήσης μηνιαία",
    "Data to send" : "Δεδομένα προς αποστολή",
    "Last report sent on: %s" : "Η τελευταία αναφορά στάλθηκε στις: %s",
    "Last report" : "Τελευταία αναφορά",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Στείλει ανώνυμα δεδομένα στο Nextcloud για να μας βοηθήσει να βελτιώσουμε το Nextcloud. Εσείς\n         έχετε πάντα τον πλήρη έλεγχο του περιεχομένου που αποστέλλεται στο Nextcloud και μπορείτε να το απενεργοποιήσετε\n       ξανά ανά πάσα στιγμή."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.8.tgz: nextcloud/apps/survey_client/l10n/el.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Η τελευταία αναφορά στάλθηκε στις: {on}",
    "An error occurred while sending your report." : "Παρουσιάστηκε σφάλμα κατά την αποστολή της αναφοράς σας.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Λίστα εφαρμογών <em>(για κάθε εφαρμογή: όνομα, έκδοση, είναι ενεργοποιημένη;)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Περιβάλλον βάσης δεδομένων <em>(Τύπος, έκδοση, μέγεθος βάσης δεδομένων) </em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Πληροφορίες κρυπτογράφησης <em>(είναι ενεργοποιημένες; , ποιό είναι το προεπιλεγμένο άρθρωμα) </em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Αριθμός διαμοιρασμών<em>(ανά τύπο και ρύθμιση δικαιωμάτων)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "Περιβάλλον PHP <em>(έκδοση, όριο μνήμης, μέγιστος χρόνος εκτέλεσης, μέγιστο μέγεθος αρχείου)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Λεπτομέρειες διακομιστή <em>(έκδοση, χρήση memcache, κατάσταση των locking/previews/avatars)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Στατιστικά <em>(αριθμός αρχείων, χρηστών, μονάδων αποθήκευσης ανά τύπο, σχόλια και ετικέτες)</em>",
    "Usage survey" : "Έρευνα χρήσης",
    "Help improve Nextcloud" : "Βοηθήστε στην βελτίωση του Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Θέλετε να μας βοηθήσετε να βελτιώσουμε το Nextcloud παρέχοντας κάποια ανώνυμα δεδομένα σχετικά με τις ρύθμισεις και τη χρήση; Μπορείτε να την απενεργοποιήσετε ανά πάσα στιγμή από τις ρυθμίσεις διαχειριστή ξανά.",
    "Not now" : "Όχι τώρα",
    "Send usage" : "Αποστολή χρήσης",
    "Never" : "Ποτέ",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Στέλνει ανώνυμα δεδομένα στο Nextcloud για να μας βοηθήσει να βελτιώσουμε το Nextcloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "Στείλει ανώνυμα δεδομένα στο Nextcloud για να μας βοηθήσει να βελτιώσουμε το Nextcloud. Εσείς\n\t\tέχετε πάντα τον πλήρη έλεγχο του περιεχομένου που αποστέλλεται στο Nextcloud και μπορείτε να το απενεργοποιήσετε\n\t\tξανά ανά πάσα στιγμή.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Μπορείτε να βοηθήσετε στη βελτίωση του Nextcloud με την αποστολή ορισμένων στοιχείων σχετικά με τις τρέχουσες ρυθμίσεις και τη χρήση.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Παίρνουμε στα σοβαρά τα προσωπικά σας δεδομένα. Η αποστολή δεδομένων είναι απενεργοποιημένη από προεπιλογή και αν επιλέξετε να την ενεργοποιήσετε, θα είναι ανώνυμη πρώτα και θα σας δοθεί η δυνατότητα τι ακριβώς θα μοιραστείτε. Μόλις ληφθεί μια αναφορά, η προηγούμενη καταργείται. Μεταφορτώστε μια καθαρή αναφορά για να διαγράψετε όλα τα δεδομένα που είναι αποθηκευμένα στο διακομιστή.",
    "Send new report now" : "Αποστολή νέας αναφοράς τώρα",
    "Send usage survey monthly" : "Αποστολή έρευνας χρήσης μηνιαία",
    "Data to send" : "Δεδομένα προς αποστολή",
    "Last report sent on: %s" : "Η τελευταία αναφορά στάλθηκε στις: %s",
    "Last report" : "Τελευταία αναφορά",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Στείλει ανώνυμα δεδομένα στο Nextcloud για να μας βοηθήσει να βελτιώσουμε το Nextcloud. Εσείς\n         έχετε πάντα τον πλήρη έλεγχο του περιεχομένου που αποστέλλεται στο Nextcloud και μπορείτε να το απενεργοποιήσετε\n       ξανά ανά πάσα στιγμή."
},
"nplurals=2; plural=(n != 1);");
